@@ -38,26 +38,27 @@ async def create_queues(queues, channel):
         dlx_name = queue.get('dlx', f"{queue['name']}_dlx")
         dlq_name = queue.get('dlq', f"{queue['name']}_dlq")
 
-        q_args = {
-            **{"x-queue-type": queue.get("type", "quorum")},
-            **queue.get("arguments", {})
-        }
-        await channel.declare_exchange(
-            dlx_name,
-            type=aio_pika.ExchangeType.TOPIC,
-            durable=True,
-            auto_delete=False
-        )
+        if not queue.get("no_dl", False):
+            q_args = {
+                **{"x-queue-type": queue.get("type", "quorum")},
+                **queue.get("arguments", {})
+            }
+            await channel.declare_exchange(
+                dlx_name,
+                type=aio_pika.ExchangeType.TOPIC,
+                durable=True,
+                auto_delete=False
+            )
 
-        dlq = await channel.declare_queue(
-            dlq_name,
-            arguments=q_args,
-            durable=True,
-            robust=True,
-            auto_delete=False,
-            exclusive=False
-        )
-        await dlq.bind(dlx_name, routing_key='#')
+            dlq = await channel.declare_queue(
+                dlq_name,
+                arguments=q_args,
+                durable=True,
+                robust=True,
+                auto_delete=False,
+                exclusive=False
+            )
+            await dlq.bind(dlx_name, routing_key='#')
 
         q_args = queue.get("arguments", {})
         if queue.get('x-dead-letter-exchange', dlx_name):
